Running Analyzer on Single File
Date: 07 23, 2001 10:07:42 AM

# Running Analyzers

You can run the analyzer on files one at a time or you can run the analyzer on multiple files contained in a tree of folders.

To run an analyzer on a single file:

1. Select the file in the Text Tab.

2. Click the Run button on the Workspace Toolbar.

To run an analyzer on a tree of folders:

1. Select the top level folder in the Text Tab.

2. Click the Run button on the Workspace Toolbar.

Note: Log files generated for the text are placed under (indented and to the right of) the text file. To generate log files, the Toggle Generate Logs button must be selected before the analyzer is run. A red checkmark on a file in the Text Tab indicates the file has been analyzed.

Tip: You can also select Run from the Analyzer Menu.

##